# {{ project_name }} Runtime Configuration
# Generated by ABI-Core scaffolding

project:
  name: "{{ project_name }}"
  description: "{{ description }}"
  domain: "{{ domain }}"
  version: "{{ version | default('1.0.0') }}"
  created: "{{ timestamp | default('2024-01-01T00:00:00Z') }}"

agents: {}

services:
{% if with_semantic_layer %}
  semantic_layer:
    name: "Semantic Layer"
    type: "semantic-layer"
    port: 10100
    enabled: true
    config:
      embedding_model: "{{ embedding_model | default('nomic-embed-text:v1.5') }}"
      weaviate_url: "{{ weaviate_url | default('http://localhost:8080') }}"
      agent_cards_dir: "./services/semantic_layer/mcp_server/agent_cards"
{% endif %}
{% if with_guardian %}
  guardian:
    name: "Guardian Security"
    type: "guardian"
    port: 11438
    enabled: true
    config:
      opa_url: "{{ opa_url | default('http://localhost:8181') }}"
      max_risk_threshold: {{ max_risk_threshold | default('0.7') }}
      emergency_log_dir: "./services/guardian/emergency_logs"
{% endif %}

policies:
{% if with_guardian %}
  semantic_access:
    type: "opa"
    file: "./services/guardian/opa/policies/semantic_access.rego"
    enabled: true
{% endif %}

runtime:
  mode: "{{ mode | default('development') }}"
  log_level: "{{ log_level | default('INFO') }}"
  debug: {{ debug | default('true') }}
  ports:
    start: 8000
    end: 8100
  
domain_config:
  domain: "{{ domain }}"
{% if domain == 'finance' %}
  finance:
    compliance_required: {{ compliance_required | default('true') }}
    audit_all_transactions: {{ audit_all_transactions | default('true') }}
    max_transaction_amount: {{ max_transaction_amount | default('10000.0') }}
{% elif domain == 'healthcare' %}
  healthcare:
    hipaa_compliance: {{ hipaa_compliance | default('true') }}
    phi_protection: {{ phi_protection | default('true') }}
    audit_patient_access: {{ audit_patient_access | default('true') }}
{% endif %}