# ABI Core Framework
abi-core-ai

# Agent dependencies
fastapi>=0.100.0
uvicorn[standard]>=0.20.0
pydantic>=2.0.0
starlette>=0.27.0

# A2A Protocol
a2a-sdk
mcp
fastmcp
mcp-toolbox

# AI and LLM
langchain>=0.1.0
langchain-core>=0.2.20
langchain-ollama>=0.1.0
langchain-community>=0.1.0
langgraph>=0.1.0

# HTTP and Networking
httpx>=0.25.0
requests>=2.31.0
aiohttp>=3.8.0

# Data and Storage
redis>=4.5.0
tinydb>=4.7.0
networkx>=3.0.0

# Utilities
jinja2>=3.1.0
pyyaml>=6.0.0
psutil>=5.9.0

{% if with_web_interface %}
sse-starlette>=1.6.0
{% endif %}